ReceivedODIDMessage class

Constructors

ReceivedODIDMessage({required ODIDMessage odidMessage, required ODIDMetadata metadata, required DateTime receivedTimestamp})

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata → ODIDMetadata
final
odidMessage → ODIDMessage
final
receivedTimestamp → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ODIDMessage? odidMessage, ODIDMetadata? metadata, DateTime? receivedTimestamp}) → ReceivedODIDMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited